@@ -23,10 +23,10 @@ const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const Gtk = imports.gi.Gtk;
+const Gdk = imports.gi.Gdk;
 
 const MainWindow = imports.mainWindow;
 const Preferences = imports.preferences;
-const Util = imports.util;
 
 var SIGINT = 2;
 var SIGTERM = 15;
@@ -38,6 +38,21 @@ var Application = GObject.registerClass(class Application extends Gtk.Applicatio
     _init() {
         super._init({ application_id: pkg.name });
         GLib.set_application_name(_("SoundRecorder"));
+        GLib.set_prgname("gnome-sound-recorder");
+
+        this.add_main_option('version', 'v'.charCodeAt(0), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
+                             "Print version information and exit", null);
+
+        this.connect('handle-local-options', (app, options) => {
+            if (options.contains('version')) {
+                print(pkg.version);
+                /* quit the invoked process after printing the version number
+                 * leaving the running instance unaffected
+                 */
+                return 0;
+            }
+            return -1;
+        });
     }
 
     _initAppMenu() {
@@ -64,12 +79,12 @@ var Application = GObject.registerClass(class Application extends Gtk.Applicatio
     vfunc_startup() {
         super.vfunc_startup();
 
-        Util.loadStyleSheet();
+        this._loadStyleSheet();
         log(_("Sound Recorder started"));
         Gst.init(null);
         this._initAppMenu();
         application = this;
-        settings = new Gio.Settings({ schema: 'org.gnome.SoundRecorder' });
+        settings = new Gio.Settings({ schema: pkg.name });
         this.ensure_directory();
     }
 
@@ -84,6 +99,8 @@ var Application = GObject.registerClass(class Application extends Gtk.Applicatio
 
     vfunc_activate() {
         (this.window = new MainWindow.MainWindow({ application: this })).show();
+        if (pkg.name.endsWith('Devel'))
+            this.window.get_style_context().add_class("devel");
     }
 
     onWindowDestroy() {
@@ -140,6 +157,14 @@ var Application = GObject.registerClass(class Application extends Gtk.Applicatio
          settings.set_double("speaker-volume", level);
     }
 
+    _loadStyleSheet() {
+        let provider = new Gtk.CssProvider();
+        provider.load_from_resource('/org/gnome/SoundRecorder/application.css');
+        Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(),
+                                                 provider,
+                                                 Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION);
+    }
+
     _showAbout() {
         let aboutDialog = new Gtk.AboutDialog();
         aboutDialog.artists = [ 'Reda Lazri <the.red.shortcut@gmail.com>',
@@ -152,7 +177,7 @@ var Application = GObject.registerClass(class Application extends Gtk.Applicatio
         aboutDialog.program_name = _("Sound Recorder");
         aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + String.fromCharCode(0x2013) + 'Meg Ford';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
-        aboutDialog.logo_icon_name = 'org.gnome.SoundRecorder';
+        aboutDialog.logo_icon_name = pkg.name;
         aboutDialog.version = pkg.version;
         aboutDialog.website = 'https://wiki.gnome.org/Apps/SoundRecorder';
         aboutDialog.wrap_license = true;
