@@ -1,3 +1,4 @@
+/* exported OffsetController DisplayTime */
 /*
  * Copyright 2013 Meg Ford
  * This library is free software; you can redistribute it and/or
@@ -24,7 +25,6 @@ const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const GstPbutils = imports.gi.GstPbutils;
-const Lang = imports.lang;
 const Signals = imports.signals;
 
 const Listview = imports.listview;
@@ -35,21 +35,19 @@ const _OFFSET_STEP = 20;
 let CurrentEndIdx;
 let totItems;
 
-const OffsetController = new Lang.Class({
-    Name: 'OffsetController',
-
-    _init: function(context) {
+var OffsetController = class OffsetController {
+    constructor(context) {
         this._offset = 0;
         this._itemCount = 0;
         this._context = context;
         CurrentEndIdx = _OFFSET_STEP;
-    },
+    }
 
-    getOffset: function() {
+    getOffset() {
         return this._offset;
-    },
+    }
 
-    getEndIdx: function() {
+    getEndIdx() {
         totItems = MainWindow.list.getItemCount();
         if (CurrentEndIdx < totItems) {
             this.endIdx = CurrentEndIdx -1;
@@ -58,21 +56,19 @@ const OffsetController = new Lang.Class({
         }
 
         return this.endIdx;
-    },
+    }
 
-    increaseEndIdxStep: function() {
+    increaseEndIdxStep() {
         CurrentEndIdx += _OFFSET_STEP;
-    },
+    }
 
-    getcidx: function() {
+    getcidx() {
         return CurrentEndIdx;
     }
-});
+}
 
-const DisplayTime = new Lang.Class({
-    Name: 'DisplayTime',
-
-    getDisplayTime: function(mtime) {
+var DisplayTime = class DisplayTime {
+    getDisplayTime(mtime) {
         let text = "";
         let DAY = 86400000000;
         let now = GLib.DateTime.new_now_local();
@@ -111,6 +107,4 @@ const DisplayTime = new Lang.Class({
         }
         return text;
     }
-});
-
-
+}
