@@ -1,3 +1,4 @@
+/* exported InfoDialog */
 /*
  * Copyright 2013 Meg Ford
  * This library is free software; you can redistribute it and/or
@@ -21,17 +22,14 @@
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 
 const _ = imports.gettext.gettext;
 const C_ = imports.gettext.pgettext;
 
 const MainWindow = imports.mainWindow;
 
-const InfoDialog = new Lang.Class({
-    Name: 'InfoDialog',
-
-    _init: function(fileNav) {
+var InfoDialog = class InfoDialog {
+    constructor(fileNav) {
         let fileName = fileNav;
 
         this._file = Gio.File.new_for_uri(fileNav.uri);
@@ -45,13 +43,14 @@ const InfoDialog = new Lang.Class({
         header.set_show_close_button(false);
         this.widget.set_titlebar(header);
 
+
         let cancelButton = new Gtk.Button({ label: _("Cancel") });
-        cancelButton.connect("clicked", Lang.bind(this, this.onCancelClicked));
+        cancelButton.connect("clicked", () => this.onCancelClicked());
 
         header.pack_start(cancelButton);
 
         let doneButton = new Gtk.Button({ label: _("Done") });
-        doneButton.connect("clicked", Lang.bind(this, this.onDoneClicked));
+        doneButton.connect("clicked", () => this.onDoneClicked());
 
         header.pack_end(doneButton);
 
@@ -154,15 +153,15 @@ const InfoDialog = new Lang.Class({
         grid.attach_next_to(this._mediaTypeData, this._mediaType, Gtk.PositionType.RIGHT, 2, 1);
 
         this.widget.show_all();
-    },
+    }
 
-    onDoneClicked: function() {
+    onDoneClicked() {
         let newFileName = this._fileNameEntry.get_text();
         this._file.set_display_name_async(newFileName, GLib.PRIORITY_DEFAULT, null, null);
         this.widget.destroy();
-    },
+    }
 
-    onCancelClicked: function() {
+    onCancelClicked() {
         this.widget.destroy();
     }
-});
+}
