@@ -1,3 +1,4 @@
+/* exported Listview */
 /*
  * Copyright 2013 Meg Ford
  * This library is free software; you can redistribute it and/or
@@ -24,7 +25,6 @@ const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const GstPbutils = imports.gi.GstPbutils;
-const Lang = imports.lang;
 const Signals = imports.signals;
 
 const AudioProfile = imports.audioProfile;
@@ -62,115 +62,110 @@ let startRecording = false;
 let stopVal = null;
 var trackNumber = 0;
 
-const Listview = new Lang.Class({
-    Name: "Listview",
-
-    _init: function() {
+var Listview = class Listview {
+    constructor() {
         stopVal = EnumeratorState.ACTIVE;
         allFilesInfo = [];
 
         // Save a reference to the savedir to quickly access it
         this._saveDir = Gio.Application.get_default().saveDir;
-    },
+    }
 
-    monitorListview: function() {
+    monitorListview() {
         this.dirMonitor = this._saveDir.monitor_directory(Gio.FileMonitorFlags.WATCH_MOVES, null);
-        this.dirMonitor.connect('changed', this._onDirChanged);
-    },
+        this.dirMonitor.connect('changed', (dirMonitor, file1, file2, eventType) => this._onDirChanged(dirMonitor, file1, file2, eventType));
+    }
 
-    enumerateDirectory: function() {
+    enumerateDirectory() {
         this._saveDir.enumerate_children_async('standard::display-name,time::created,time::modified',
                                      Gio.FileQueryInfoFlags.NONE,
                                      GLib.PRIORITY_LOW,
-                                     null, Lang.bind(this,
-                                     this._onEnumerator));
-    },
+                                     null,
+                                     (obj, res) => this._onEnumerator(obj, res));
+    }
 
-    _onEnumerator: function(obj, res) {
+    _onEnumerator(obj, res) {
         this._enumerator = obj.enumerate_children_finish(res);
 
         if (this._enumerator == null)
             log("The contents of the Recordings directory were not indexed.");
         else
             this._onNextFileComplete();
-    },
+    }
 
-    _onNextFileComplete: function () {
+    _onNextFileComplete () {
         fileInfo = [];
         try{
-            this._enumerator.next_files_async(20, GLib.PRIORITY_DEFAULT, null, Lang.bind(this,
-                function(obj, res) {
-                    let files = obj.next_files_finish(res);
+            this._enumerator.next_files_async(20, GLib.PRIORITY_DEFAULT, null, (obj, res) => {
+                let files = obj.next_files_finish(res);
 
-                    if (files.length) {
-                        files.forEach(Lang.bind(this,
-                            function(file) {
-                                let returnedName = file.get_attribute_as_string("standard::display-name");
-                                try {
-                                    let returnedNumber = parseInt(returnedName.split(" ")[1]);
-                                    if (returnedNumber > trackNumber)
-                                        trackNumber = returnedNumber;
+                if (files.length) {
+                    files.forEach((file) => {
+                        let returnedName = file.get_attribute_as_string("standard::display-name");
+                        try {
+                            let returnedNumber = parseInt(returnedName.split(" ")[1]);
+                            if (returnedNumber > trackNumber)
+                                trackNumber = returnedNumber;
 
-                                }  catch (e) {
-                                    if (!e instanceof TypeError)
-                                        throw e;
+                        }  catch (e) {
+                            if (!e instanceof TypeError)
+                                throw e;
 
-                                    log("Tracknumber not returned");
-                                    // Don't handle the error
-                                }
-                                let finalFileName = GLib.build_filenamev([this._saveDir.get_path(),
-                                                                          returnedName]);
-                                let fileUri = GLib.filename_to_uri(finalFileName, null);
-                                let timeVal = file.get_modification_time();
-                                let date = GLib.DateTime.new_from_timeval_local(timeVal);
-                                let dateModifiedSortString = date.format("%Y%m%d%H%M%S");
-                                let dateTime = GLib.DateTime.new_from_timeval_local(timeVal);
-                                let dateModifiedDisplayString = MainWindow.displayTime.getDisplayTime(dateTime);
-                                let dateCreatedYes = file.has_attribute("time::created");
-                                let dateCreatedString = null;
-                                if (this.dateCreatedYes) {
-                                    let dateCreatedVal = file.get_attribute_uint64("time::created");
-                                    let dateCreated = GLib.DateTime.new_from_timeval_local(dateCreatedVal);
-                                    dateCreatedString = MainWindow.displayTime.getDisplayTime(dateCreated);
-                                }
-
-                                fileInfo =
-                                    fileInfo.concat({ appName: null,
-                                                      dateCreated: dateCreatedString,
-                                                      dateForSort: dateModifiedSortString,
-                                                      dateModified: dateModifiedDisplayString,
-                                                      duration: null,
-                                                      fileName: returnedName,
-                                                      mediaType: null,
-                                                      title: null,
-                                                      uri: fileUri });
-                            }));
-                        this._sortItems(fileInfo);
-                    } else {
-                        stopVal = EnumeratorState.CLOSED;
-                        this._enumerator.close(null);
-
-                        if (MainWindow.offsetController.getEndIdx() == -1) {
-                             if (listType == ListType.NEW) {
-                                MainWindow.view.listBoxAdd();
-                                MainWindow.view.scrolledWinAdd();
-                            } else if (listType == ListType.REFRESH) {
-                                MainWindow.view.scrolledWinDelete();
-                            }
-                            currentlyEnumerating = CurrentlyEnumerating.FALSE;
-                        } else {
-
-                        this._setDiscover();
+                            log("Tracknumber not returned");
+                            // Don't handle the error
                         }
-                        return;
-                   }
-                }));
+                        let finalFileName = GLib.build_filenamev([this._saveDir.get_path(),
+                                                                  returnedName]);
+                        let fileUri = GLib.filename_to_uri(finalFileName, null);
+                        let timeVal = file.get_modification_time();
+                        let date = GLib.DateTime.new_from_timeval_local(timeVal);
+                        let dateModifiedSortString = date.format("%Y%m%d%H%M%S");
+                        let dateTime = GLib.DateTime.new_from_timeval_local(timeVal);
+                        let dateModifiedDisplayString = MainWindow.displayTime.getDisplayTime(dateTime);
+                        let dateCreatedYes = file.has_attribute("time::created");
+                        let dateCreatedString = null;
+                        if (this.dateCreatedYes) {
+                            let dateCreatedVal = file.get_attribute_uint64("time::created");
+                            let dateCreated = GLib.DateTime.new_from_timeval_local(dateCreatedVal);
+                            dateCreatedString = MainWindow.displayTime.getDisplayTime(dateCreated);
+                        }
+
+                        fileInfo =
+                            fileInfo.concat({ appName: null,
+                                              dateCreated: dateCreatedString,
+                                              dateForSort: dateModifiedSortString,
+                                              dateModified: dateModifiedDisplayString,
+                                              duration: null,
+                                              fileName: returnedName,
+                                              mediaType: null,
+                                              title: null,
+                                              uri: fileUri });
+                    });
+                    this._sortItems(fileInfo);
+                } else {
+                    stopVal = EnumeratorState.CLOSED;
+                    this._enumerator.close(null);
+
+                    if (MainWindow.offsetController.getEndIdx() == -1) {
+                         if (listType == ListType.NEW) {
+                            MainWindow.view.listBoxAdd();
+                            MainWindow.view.scrolledWinAdd();
+                        } else if (listType == ListType.REFRESH) {
+                            MainWindow.view.scrolledWinDelete();
+                        }
+                        currentlyEnumerating = CurrentlyEnumerating.FALSE;
+                    } else {
+                        this._setDiscover();
+                    }
+                    return;
+               }
+            });
         } catch(e) {
             log(e);
         }
-    },
+    }
 
-    _sortItems: function(fileArr) {
+    _sortItems(fileArr) {
         allFilesInfo = allFilesInfo.concat(fileArr);
         allFilesInfo.sort(function(a, b) {
             return b.dateForSort - a.dateForSort;
@@ -179,13 +174,13 @@ const Listview = new Lang.Class({
         if (stopVal == EnumeratorState.ACTIVE) {
             this._onNextFileComplete();
         }
-    },
+    }
 
-    getItemCount: function() {
+    getItemCount() {
         return allFilesInfo.length;
-    },
+    }
 
-    _setDiscover: function() {
+    _setDiscover() {
         this._controller = MainWindow.offsetController;
         this.endIdx = this._controller.getEndIdx();
         this.idx = 0;
@@ -197,17 +192,16 @@ const Listview = new Lang.Class({
             this._discoverer.discover_uri_async(uri);
         }
         this._runDiscover();
-     },
+    }
 
-     _runDiscover: function() {
-          this._discoverer.connect('discovered', Lang.bind(this,
-            function(_discoverer, info, error) {
-                let result = info.get_result();
-                this._onDiscovererFinished(result, info, error);
-             }));
-    },
+     _runDiscover() {
+        this._discoverer.connect('discovered', (_discoverer, info, error) => {
+            let result = info.get_result();
+            this._onDiscovererFinished(result, info, error);
+        });
+    }
 
-    _onDiscovererFinished: function(res, info, err) {
+    _onDiscovererFinished(res, info, err) {
         this.result = res;
         if (this.result == GstPbutils.DiscovererResult.OK && allFilesInfo[this.idx]) {
             this.tagInfo = info.get_tags();
@@ -244,24 +238,24 @@ const Listview = new Lang.Class({
                 MainWindow.view.listBoxAdd();
                 MainWindow.view.scrolledWinAdd();
                 currentlyEnumerating = CurrentlyEnumerating.FALSE;
-            } else if (listType == ListType.REFRESH){
+            } else if (listType == ListType.REFRESH) {
                 MainWindow.view.scrolledWinDelete();
                 currentlyEnumerating = CurrentlyEnumerating.FALSE;
             }
             //return false;
         }
         this.idx++;
-    },
+    }
 
-    setListTypeNew: function() {
+    setListTypeNew() {
         listType = ListType.NEW;
-    },
+    }
 
-    setListTypeRefresh: function() {
+    setListTypeRefresh() {
         listType = ListType.REFRESH;
-    },
+    }
 
-    _onDirChanged: function(dirMonitor, file1, file2, eventType) {
+    _onDirChanged(dirMonitor, file1, file2, eventType) {
         if (eventType == Gio.FileMonitorEvent.DELETED && Gio.Application.get_default().saveDir.equal(file1)) {
             Gio.Application.get_default().ensure_directory();
             this._saveDir = Gio.Application.get_default().saveDir;
@@ -284,9 +278,9 @@ const Listview = new Lang.Class({
         else if (eventType == Gio.FileMonitorEvent.CREATED) {
             startRecording = true;
         }
-    },
+    }
 
-    _onDirChangedDeb: function(dirMonitor, file1, file2, eventType) {
+    _onDirChangedDeb(dirMonitor, file1, file2, eventType) {
         /* Workaround for Debian and Tails not recognizing Gio.FileMointor.WATCH_MOVES */
         if (eventType == Gio.FileMonitorEvent.DELETED && Gio.Application.get_default().saveDir.equal(file1)) {
             Gio.Application.get_default().ensure_directory();
@@ -309,9 +303,9 @@ const Listview = new Lang.Class({
         else if (eventType == Gio.FileMonitorEvent.CREATED) {
             startRecording = true;
         }
-    },
+    }
 
-    _getCapsForList: function(info) {
+    _getCapsForList(info) {
         let discovererStreamInfo = null;
         discovererStreamInfo = info.get_stream_info();
         let containerStreams = info.get_container_streams()[0];
@@ -345,16 +339,14 @@ const Listview = new Lang.Class({
                 // Remove the file from the array if we don't recognize it
                 allFilesInfo.splice(this.idx, 1);
         }
-    },
+    }
 
-    capTypes: function(capString) {
-    	let caps = Gst.Caps.from_string(capString);
-    	return caps;
-    },
+    capTypes(capString) {
+        let caps = Gst.Caps.from_string(capString);
+        return caps;
+    }
 
-    getFilesInfoForList: function() {
+    getFilesInfoForList() {
         return allFilesInfo;
     }
-});
-
-
+}
