@@ -1,3 +1,4 @@
+/* exported Play */
 /*
  * Copyright 2013 Meg Ford
  * This library is free software; you can redistribute it and/or
@@ -24,7 +25,6 @@ const Gst = imports.gi.Gst;
 const GstAudio = imports.gi.GstAudio;
 const GstPbutils = imports.gi.GstPbutils;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -47,10 +47,8 @@ let errorDialogState;
 
 const _TENTH_SEC = 100000000;
 
-const Play = new Lang.Class({
-    Name: "Play",
-
-    _playPipeline: function() {
+var Play = class Play {
+    _playPipeline() {
         errorDialogState = ErrState.OFF;
         let uri = this._fileToPlay.get_uri();
         this.play = Gst.ElementFactory.make("playbin", "play");
@@ -60,16 +58,14 @@ const Play = new Lang.Class({
         this.clock = this.play.get_clock();
         this.playBus = this.play.get_bus();
         this.playBus.add_signal_watch();
-        this.playBus.connect("message", Lang.bind(this,
-            function(playBus, message) {
+        this.playBus.connect("message", (playBus, message) => {
+            if (message != null) {
+                this._onMessageReceived(message);
+            }
+        });
+    }
 
-                if (message != null) {
-                    this._onMessageReceived(message);
-                }
-            }));
-    },
-
-    startPlaying: function() {
+    startPlaying() {
         this.baseTime = 0;
 
         if (!this.play || this.playState == PipelineStates.STOPPED ) {
@@ -91,11 +87,11 @@ const Play = new Lang.Class({
         } else if (this.ret == Gst.StateChangeReturn.SUCCESS) {
             MainWindow.view.setVolume();
         }
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy, this.play);
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy, this.play);
-    },
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy);
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy);
+    }
 
-    pausePlaying: function() {
+    pausePlaying() {
         this.play.set_state(Gst.State.PAUSED);
         this.playState = PipelineStates.PAUSED;
 
@@ -103,15 +99,15 @@ const Play = new Lang.Class({
             GLib.source_remove(this.timeout);
             this.timeout = null;
         }
-    },
+    }
 
-    stopPlaying: function() {
+    stopPlaying() {
         if (this.playState != PipelineStates.STOPPED) {
             this.onEnd();
         }
-    },
+    }
 
-    onEnd: function() {
+    onEnd() {
         this.play.set_state(Gst.State.NULL);
         this.playState = PipelineStates.STOPPED;
         this.playBus.remove_signal_watch();
@@ -126,13 +122,13 @@ const Play = new Lang.Class({
             MainWindow.wave.endDrawing();
 
         errorDialogState = ErrState.OFF;
-    },
+    }
 
-    onEndOfStream: function() {
+    onEndOfStream() {
         MainWindow.view.onPlayStopClicked();
-    },
+    }
 
-    _onMessageReceived: function(message) {
+    _onMessageReceived(message) {
         this.localMsg = message;
         let msg = message.type;
         switch(msg) {
@@ -171,15 +167,15 @@ const Play = new Lang.Class({
             }
             break;
         }
-    },
+    }
 
-    getPipeStates: function() {
+    getPipeStates() {
         return this.playState;
-    },
+    }
 
-    _updateTime: function() {
-        let time = this.play.query_position(Gst.Format.TIME, null)[1]/Gst.SECOND;
-        this.trackDuration = this.play.query_duration(Gst.Format.TIME, null)[1];
+    _updateTime() {
+        let time = this.play.query_position(Gst.Format.TIME)[1]/Gst.SECOND;
+        this.trackDuration = this.play.query_duration(Gst.Format.TIME)[1];
         this.trackDurationSecs = this.trackDuration/Gst.SECOND;
 
         if (time >= 0 && this.playState != PipelineStates.STOPPED) {
@@ -210,34 +206,34 @@ const Play = new Lang.Class({
         }
 
         return true;
-    },
+    }
 
-    queryPosition: function() {
+    queryPosition() {
         let position = 0;
         while (position == 0) {
-            position = this.play.query_position(Gst.Format.TIME, null)[1]/Gst.SECOND;
+            position = this.play.query_position(Gst.Format.TIME)[1]/Gst.SECOND;
         }
 
         return position;
-    },
+    }
 
-    updatePosition: function() {
+    updatePosition() {
         if (!this.timeout) {
-            this.timeout = GLib.timeout_add(GLib.PRIORITY_DEFAULT, 10, Lang.bind(this,
-                this._updateTime));
+            this.timeout = GLib.timeout_add(GLib.PRIORITY_DEFAULT, 10, () =>
+                this._updateTime());
         }
-    },
+    }
 
-    setVolume: function(value) {
+    setVolume(value) {
         this.play.set_volume(GstAudio.StreamVolumeFormat.CUBIC, value);
-    },
+    }
 
-    passSelected: function(selected) {
+    passSelected(selected) {
         this._selected = selected;
         this._fileToPlay = MainWindow.view.loadPlay(this._selected);
-    },
+    }
 
-    _showErrorDialog: function(errorStrOne, errorStrTwo) {
+    _showErrorDialog(errorStrOne, errorStrTwo) {
         if (errorDialogState == ErrState.OFF) {
             let errorDialog = new Gtk.MessageDialog ({ destroy_with_parent: true,
                                                        buttons: Gtk.ButtonsType.OK,
@@ -250,13 +246,11 @@ const Play = new Lang.Class({
                 errorDialog.set_property('secondary-text', errorStrTwo);
 
             errorDialog.set_transient_for(Gio.Application.get_default().get_active_window());
-            errorDialog.connect ('response', Lang.bind(this,
-                function() {
-                    errorDialog.destroy();
-                    this.onEndOfStream();
-                }));
+            errorDialog.connect ('response', () => {
+                errorDialog.destroy();
+                this.onEndOfStream();
+            });
             errorDialog.show();
         }
     }
-});
-
+}
