@@ -1,3 +1,4 @@
+/* exported Record */
 /*
  * Copyright 2013 Meg Ford
  * This library is free software; you can redistribute it and/or
@@ -26,7 +27,6 @@ const GstAudio = imports.gi.GstAudio;
 const GstPbutils = imports.gi.GstPbutils;
 const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
@@ -44,21 +44,19 @@ const PipelineStates = {
 const ErrState = {
     OFF: 0,
     ON: 1
-}
+};
 
 const Channels = {
     MONO: 0,
     STEREO: 1
-}
+};
 
 const _TENTH_SEC = 100000000;
 
 let errorDialogState;
 
-const Record = new Lang.Class({
-    Name: "Record",
-
-    _recordPipeline: function() {
+var Record = class Record {
+    _recordPipeline() {
         errorDialogState = ErrState.OFF;
         this.baseTime = 0;
         this._view = MainWindow.view;
@@ -97,35 +95,32 @@ const Record = new Lang.Class({
         this.clock = this.pipeline.get_clock();
         this.recordBus = this.pipeline.get_bus();
         this.recordBus.add_signal_watch();
-        this.recordBus.connect("message", Lang.bind(this,
-            function(recordBus, message) {
-
-                if (message != null) {
-                    this._onMessageReceived(message);
-                }
-            }));
+        this.recordBus.connect("message", (recordBus, message) => {
+            if (message != null) {
+                this._onMessageReceived(message);
+            }
+        });
         this.level = Gst.ElementFactory.make("level", "level");
         this.pipeline.add(this.level);
         this.volume = Gst.ElementFactory.make("volume", "volume");
         this.pipeline.add(this.volume);
         this.ebin = Gst.ElementFactory.make("encodebin", "ebin");
-        this.ebin.connect("element-added", Lang.bind(this,
-            function(ebin, element) {
-                let factory = element.get_factory();
+        this.ebin.connect("element-added", (ebin, element) => {
+            let factory = element.get_factory();
 
-                if (factory != null) {
-                        this.hasTagSetter = factory.has_interface("GstTagSetter");
-                        if (this.hasTagSetter == true) {
-                            this.taglist = Gst.TagList.new_empty();
-                            this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_APPLICATION_NAME, _("Sound Recorder"));
-                            element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
-                            this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_TITLE, this.initialFileName);
-                            element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
-                            this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_DATE_TIME, this.gstreamerDateTime);
-                            element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
-                    }
+            if (factory != null) {
+                this.hasTagSetter = factory.has_interface("GstTagSetter");
+                if (this.hasTagSetter == true) {
+                    this.taglist = Gst.TagList.new_empty();
+                    this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_APPLICATION_NAME, _("Sound Recorder"));
+                    element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
+                    this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_TITLE, this.initialFileName);
+                    element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
+                    this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_DATE_TIME, this.gstreamerDateTime);
+                    element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
                 }
-            }));
+            }
+        });
         this.pipeline.add(this.ebin);
         let ebinProfile = this.ebin.set_property("profile", this._mediaProfile);
         let srcpad = this.ebin.get_static_pad("src");
@@ -151,21 +146,21 @@ const Record = new Lang.Class({
             this.onEndOfStream();
         }
 
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy, this.pipeline);
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy, this.pipeline);
-    },
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy);
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy);
+    }
 
-    _updateTime: function() {
-        let time = this.pipeline.query_position(Gst.Format.TIME, null)[1]/Gst.SECOND;
+    _updateTime() {
+        let time = this.pipeline.query_position(Gst.Format.TIME)[1]/Gst.SECOND;
 
         if (time >= 0) {
             this._view.setLabel(time, 0);
         }
 
         return true;
-    },
+    }
 
-    startRecording: function(profile) {
+    startRecording(profile) {
         this.profile = profile;
         this._audioProfile = MainWindow.audioProfile;
         this._mediaProfile = this._audioProfile.mediaProfile();
@@ -190,11 +185,11 @@ const Record = new Lang.Class({
         }
 
         if (!this.timeout) {
-            this.timeout = GLib.timeout_add(GLib.PRIORITY_DEFAULT, MainWindow._SEC_TIMEOUT, Lang.bind(this, this._updateTime));
+            this.timeout = GLib.timeout_add(GLib.PRIORITY_DEFAULT, MainWindow._SEC_TIMEOUT, () => this._updateTime());
         }
-    },
+    }
 
-    stopRecording: function() {
+    stopRecording() {
         let sent = this.pipeline.send_event(Gst.Event.new_eos());
 
         if (this.timeout) {
@@ -204,9 +199,9 @@ const Record = new Lang.Class({
 
         if (MainWindow.wave != null)
             MainWindow.wave.endDrawing();
-    },
+    }
 
-    onEndOfStream: function() {
+    onEndOfStream() {
         this.pipeline.set_state(Gst.State.NULL);
         this.pipeState = PipelineStates.STOPPED;
 
@@ -215,9 +210,9 @@ const Record = new Lang.Class({
 
         this._updateTime();
         errorDialogState = ErrState.OFF;
-    },
+    }
 
-    _onMessageReceived: function(message) {
+    _onMessageReceived(message) {
         this.localMsg = message;
         let msg = message.type;
         switch(msg) {
@@ -297,15 +292,15 @@ const Record = new Lang.Class({
             errorDialogState = ErrState.ON;
             break;
         }
-    },
+    }
 
-    setVolume: function(value) {
+    setVolume(value) {
         if (this.volume) {
             this.volume.set_volume(GstAudio.StreamVolumeFormat.CUBIC, value);
         }
-    },
+    }
 
-    _getChannels: function() {
+    _getChannels() {
 
         let channels = null;
         let channelsPref = Application.application.getChannelsPreferences();
@@ -324,9 +319,9 @@ const Record = new Lang.Class({
         }
 
         return channels;
-    },
+    }
 
-    _showErrorDialog: function(errorStrOne, errorStrTwo) {
+    _showErrorDialog(errorStrOne, errorStrTwo) {
         if (errorDialogState == ErrState.OFF) {
             let errorDialog = new Gtk.MessageDialog ({ modal: true,
                                                        destroy_with_parent: true,
@@ -340,21 +335,18 @@ const Record = new Lang.Class({
                 errorDialog.set_property("secondary-text", errorStrTwo);
 
             errorDialog.set_transient_for(Gio.Application.get_default().get_active_window());
-            errorDialog.connect("response", Lang.bind(this,
-                function() {
-                    errorDialog.destroy();
-                    MainWindow.view.onRecordStopClicked();
-                    this.onEndOfStream();
-                }));
+            errorDialog.connect("response", () => {
+                errorDialog.destroy();
+                MainWindow.view.onRecordStopClicked();
+                this.onEndOfStream();
+            });
             errorDialog.show();
         }
     }
-});
+}
 
-const BuildFileName = new Lang.Class({
-    Name: "BuildFileName",
-
-    buildInitialFilename: function() {
+const BuildFileName = class BuildFileName {
+    buildInitialFilename() {
         var fileExtensionName = MainWindow.audioProfile.fileExtensionReturner();
         var dir = Gio.Application.get_default().saveDir;
         this.dateTime = GLib.DateTime.new_now_local();
@@ -365,15 +357,13 @@ const BuildFileName = new Lang.Class({
         this.clip = dir.get_child_for_display_name(clipName);
         var file = this.clip.get_path();
         return file;
-    },
+    }
 
-    getTitle: function() {
+    getTitle() {
         return this.clip;
-    },
+    }
 
-    getOrigin: function() {
+    getOrigin() {
         return this.dateTime;
     }
-});
-
-
+}
