@@ -1,3 +1,4 @@
+/* exported WaveForm */
 /*
 * Copyright 2013 Meg Ford
 * This library is free software; you can redistribute it and/or
@@ -26,7 +27,6 @@ const GObject = imports.gi.GObject;
 const Gst = imports.gi.Gst;
 const GstAudio = imports.gi.GstAudio;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const _ = imports.gettext.gettext;
@@ -45,10 +45,8 @@ const WaveType = {
     PLAY: 1
 };
 
-const WaveForm = new Lang.Class({
-    Name: 'WaveForm',
-
-    _init: function(grid, file) {
+var WaveForm = class WaveForm {
+    constructor(grid, file) {
         this._grid = grid;
 
         let placeHolder = -100;
@@ -78,7 +76,7 @@ const WaveForm = new Lang.Class({
             this._grid.add(this.drawing);
         }
 
-        this.drawing.connect("draw", Lang.bind(this, this.fillSurface));
+        this.drawing.connect("draw", (drawing, cr) => this.fillSurface(drawing, cr));
         this.drawing.show_all();
         this._grid.show_all();
 
@@ -86,30 +84,28 @@ const WaveForm = new Lang.Class({
             this._launchPipeline();
             this.startGeneration();
         }
-    },
+    }
 
-    _launchPipeline: function() {
+    _launchPipeline() {
         this.pipeline =
             Gst.parse_launch("uridecodebin name=decode uri=" + this._uri + " ! audioconvert ! audio/x-raw,channels=2 ! level name=level interval=100000000 post-messages=true ! fakesink qos=false");
         this._level = this.pipeline.get_by_name("level");
         let decode = this.pipeline.get_by_name("decode");
         let bus = this.pipeline.get_bus();
         bus.add_signal_watch();
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy, this.pipeline);
-        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy, this.pipeline);
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGINT, Application.application.onWindowDestroy);
+        GLib.unix_signal_add(GLib.PRIORITY_DEFAULT, Application.SIGTERM, Application.application.onWindowDestroy);
 
         this.nSamples = Math.ceil(this.duration / INTERVAL);
 
-        bus.connect("message", Lang.bind(this,
-            function(bus, message) {
+        bus.connect("message", (bus, message) => {
+            if (message != null) {
+                this._messageCb(message);
+            }
+        });
+    }
 
-                if (message != null) {
-                    this._messageCb(message);
-                }
-            }));
-    },
-
-    _messageCb: function(message) {
+    _messageCb(message) {
         let msg = message.type;
 
         switch(msg) {
@@ -150,17 +146,17 @@ const WaveForm = new Lang.Class({
             this.stopGeneration();
             break;
         }
-    },
+    }
 
-    startGeneration: function() {
+    startGeneration() {
         this.pipeline.set_state(Gst.State.PLAYING);
-    },
+    }
 
-    stopGeneration: function() {
+    stopGeneration() {
         this.pipeline.set_state(Gst.State.NULL);
-    },
+    }
 
-    fillSurface: function(drawing, cr) {
+    fillSurface(drawing, cr) {
         let start = 0;
 
         if (this.waveType == WaveType.PLAY) {
@@ -170,9 +166,9 @@ const WaveForm = new Lang.Class({
             }
             start = Math.floor(this.playTime);
         } else {
-
-            if (this.recordTime >= 0)
-            start = this.recordTime;
+            if (this.recordTime >= 0) {
+                start = this.recordTime;
+            }
         }
 
         let i = 0;
@@ -219,11 +215,11 @@ const WaveForm = new Lang.Class({
         cr.closePath();
         cr.strokePreserve();
         cr.setSource(gradient);
-	    cr.fillPreserve();
-	    cr.$dispose();
-    },
+        cr.fillPreserve();
+        cr.$dispose();
+    }
 
-    _drawEvent: function(playTime, recPeaks) {
+    _drawEvent(playTime, recPeaks) {
         let lastTime;
 
         if (this.waveType == WaveType.PLAY) {
@@ -251,9 +247,9 @@ const WaveForm = new Lang.Class({
                 this.drawing.queue_draw();
         }
         return true;
-    },
+    }
 
-    endDrawing: function() {
+    endDrawing() {
         if (this.pipeline)
             this.stopGeneration();
 
@@ -265,4 +261,4 @@ const WaveForm = new Lang.Class({
             log(e);
         }
     }
-});
+}
